pub struct SledStore { /* private fields */ }Implementations
Sourceimpl SledStore
impl SledStore
Sourcepub fn new(path: impl AsRef<Path>) -> Result<Self, StoreError>
pub fn new(path: impl AsRef<Path>) -> Result<Self, StoreError>
Errors
Returns an error if the database could not be opened.
Sourcepub fn new_temporary() -> Result<Self, StoreError>
pub fn new_temporary() -> Result<Self, StoreError>
Errors
Returns an error if the temporary database could not be opened.